@@ -26,9 +26,6 @@ FAILEDOPERATION_ACCOUNTUSERNOTAUTHENTICATED = 'FailedOperation.AccountUserNotAut
 # 伸缩组资源创建报错。
 FAILEDOPERATION_ASCOMMON = 'FailedOperation.AsCommon'
 
-# CLB 未知错误。
-FAILEDOPERATION_CLBUNEXPECTEDERROR = 'FailedOperation.CLBUnexpectedError'
-
 # CVM未知错误。
 FAILEDOPERATION_CVMUNEXPECTEDERROR = 'FailedOperation.CVMUnexpectedError'
 
@@ -59,6 +56,9 @@ FAILEDOPERATION_COMPONENTCLIENTUNPACK = 'FailedOperation.ComponentClientUnpack'
 # 请求(http请求)其他云服务失败。
 FAILEDOPERATION_COMPONENTCLINETHTTP = 'FailedOperation.ComponentClinetHttp'
 
+# 创建CLS客户端失败。
+FAILEDOPERATION_CREATECLSCLIENT = 'FailedOperation.CreateClsClient'
+
 # 创建CLS采集配置失败。
 FAILEDOPERATION_CREATECLSCONFIG = 'FailedOperation.CreateClsConfig'
 
@@ -137,6 +137,12 @@ FAILEDOPERATION_KUBERNETESPATCHOPERATIONERROR = 'FailedOperation.KubernetesPatch
 # 底层调用CLB未知错误。
 FAILEDOPERATION_LBCOMMON = 'FailedOperation.LbCommon'
 
+# 获取集群认证信息失败。
+FAILEDOPERATION_MARKETGETAUTHFAILED = 'FailedOperation.MarketGetAuthFailed'
+
+# 操作应用Release失败。
+FAILEDOPERATION_MARKETRELEASEOPERATION = 'FailedOperation.MarketReleaseOperation'
+
 # 修改CLS索引失败。
 FAILEDOPERATION_MODIFYCLSINDEX = 'FailedOperation.ModifyClsIndex'
 
@@ -161,12 +167,18 @@ FAILEDOPERATION_QUOTAUSGLIMIT = 'FailedOperation.QuotaUSGLimit'
 # 子账户RBAC权限不足。
 FAILEDOPERATION_RBACFORBIDDEN = 'FailedOperation.RBACForbidden'
 
+# 记录没有发现。
+FAILEDOPERATION_RECORDNOTFOUND = 'FailedOperation.RecordNotFound'
+
 # 已有相同任务执行中。
 FAILEDOPERATION_TASKALREADYRUNNING = 'FailedOperation.TaskAlreadyRunning'
 
 # 询价错误。
 FAILEDOPERATION_TRADECOMMON = 'FailedOperation.TradeCommon'
 
+# 不可预知的错误。
+FAILEDOPERATION_UNEXPECTEDERROR = 'FailedOperation.UnexpectedError'
+
 # VPC未知错误。
 FAILEDOPERATION_VPCUNEXPECTEDERROR = 'FailedOperation.VPCUnexpectedError'
 
@@ -311,6 +323,15 @@ INTERNALERROR_KUBERNETESPATCHOPERATIONERROR = 'InternalError.KubernetesPatchOper
 # 底层调用CLB未知错误。
 INTERNALERROR_LBCOMMON = 'InternalError.LbCommon'
 
+# 获取集群认证信息失败。
+INTERNALERROR_MARKETGETAUTHFAILED = 'InternalError.MarketGetAuthFailed'
+
+# 应用市场服务操作错误。
+INTERNALERROR_MARKETINTERNALSERVERERROR = 'InternalError.MarketInternalServerError'
+
+# 操作应用Release失败。
+INTERNALERROR_MARKETRELEASEOPERATION = 'InternalError.MarketReleaseOperation'
+
 # 镜像OS不支持。
 INTERNALERROR_OSNOTSUPPORT = 'InternalError.OsNotSupport'
 
@@ -464,6 +485,9 @@ RESOURCEINUSE_RESOURCEEXISTALREADY = 'ResourceInUse.ResourceExistAlready'
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
+# CVM资源不足。
+RESOURCEINSUFFICIENT_SPECIFIEDINSTANCETYPE = 'ResourceInsufficient.SpecifiedInstanceType'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
